# mmar-files

Local file storage abstraction with content deduplication for MAESTRO.

## Installation

Base functionality (local/basic storage only):

```bash
pip install mmar-files
```

With optional S3 support:

```bash
pip install mmar-files[s3]
```

TODO fill this README.md
## Assumed migration
Before:
```python
from mmar_mapi import FileStorage, FileStorageAPI
from mmar_mimpl import SettingsModel

...
class Config(SettingsModel):
    files_dir: str = "/mnt/data/maestro/files"
...
config: Config = ...
file_storage: FileStorageAPI = FileStorage(config.files_dir)
```

After
```python
from mmar_mimpl import SettingsModel

from mmar_files import FilesConfigDir, FileStorageAPI, create_file_storage

...
class Config(SettingsModel):
    files: FilesConfig = Field(default=FilesConfigDir(dir="/mnt/data/maestro/files"))
...
config: Config = ...
file_storage: FileStorageAPI = create_file_storage(config.files)
```
## License

MIT
